==> adsprod-counter-1.0.6-sources.jar: com/bxm/adsprod/counter/ticket/counter/entity/TicketWeightBaseData.java <==
package com.bxm.adsprod.counter.ticket.counter.entity;

import org.springframework.data.mongodb.core.mapping.Document;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Date;

/**
 * <pre>
 *     db.createCollection("ticket_weight_base_data", { capped : true, size : 10737418240 })
 * </pre>
 * @author allen
 * @since 1.0.0
 */
@Document(collection = "ticket_weight_base_data")
public class TicketWeightBaseData implements Serializable {

    private static final long serialVersionUID = -3452321784251387063L;

    public static final int MODELTYPE_VIEW = 6;
    public static final int MODELTYPE_CLICK = 7;

    private String position;
    private Byte settleType;
    private Integer modeltype;
    private Integer modelvalue;
    private BigInteger ticketid;
    private Date time;

    public String getPosition() {
        return position;
    }

    public void setPosition(String position) {
        this.position = position;
    }

    public Byte getSettleType() {
        return settleType;
    }

    public void setSettleType(Byte settleType) {
        this.settleType = settleType;
    }

    public Integer getModeltype() {
        return modeltype;
    }

    public void setModeltype(Integer modeltype) {
        this.modeltype = modeltype;
    }

    public Integer getModelvalue() {
        return modelvalue;
    }

    public void setModelvalue(Integer modelvalue) {
        this.modelvalue = modelvalue;
    }

    public BigInteger getTicketid() {
        return ticketid;
    }

    public void setTicketid(BigInteger ticketid) {
        this.ticketid = ticketid;
    }

    public Date getTime() {
        return time;
    }

    public void setTime(Date time) {
        this.time = time;
    }
}

==> adsprod-counter-1.1.8.4-sources.jar: com/bxm/adsprod/counter/ticket/counter/entity/TicketWeightBaseData.java <==
package com.bxm.adsprod.counter.ticket.counter.entity;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Date;

/**
 * <pre>
 *     db.createCollection("ticket_histories", { capped : true, size : 10737418240 })
 * </pre>
 * @author allen
 * @since 1.0.0
 */
public class TicketWeightBaseData implements Serializable {

    private static final long serialVersionUID = -3452321784251387063L;

    public static final String COLLECTION_NAME = "ticket_histories";

    public static final int MODELTYPE_VIEW = 6;
    public static final int MODELTYPE_CLICK = 7;

    private String position;
    private Byte settleType;
    private Integer modeltype;
    private Integer modelvalue;
    private String billid;
    private BigInteger ticketid;
    private int valid;
    private Date time;
    private BigInteger assetsId;

    public static String getCollectionName() {
        return COLLECTION_NAME;
    }

    public String getPosition() {
        return position;
    }

    public void setPosition(String position) {
        this.position = position;
    }

    public Byte getSettleType() {
        return settleType;
    }

    public void setSettleType(Byte settleType) {
        this.settleType = settleType;
    }

    public Integer getModeltype() {
        return modeltype;
    }

    public void setModeltype(Integer modeltype) {
        this.modeltype = modeltype;
    }

    public Integer getModelvalue() {
        return modelvalue;
    }

    public void setModelvalue(Integer modelvalue) {
        this.modelvalue = modelvalue;
    }

    public String getBillid() {
        return billid;
    }

    public void setBillid(String billid) {
        this.billid = billid;
    }

    public BigInteger getTicketid() {
        return ticketid;
    }

    public void setTicketid(BigInteger ticketid) {
        this.ticketid = ticketid;
    }

    public Date getTime() {
        return time;
    }

    public void setTime(Date time) {
        this.time = time;
    }

    public int getValid() {
        return valid;
    }

    public void setValid(int valid) {
        this.valid = valid;
    }

    public BigInteger getAssetsId() {
        return assetsId;
    }

    public void setAssetsId(BigInteger assetsId) {
        this.assetsId = assetsId;
    }
}
